#!/bin/sh

set -e

# ./configure doesn't fail when bearssl is missing
[ -f /lib/libbearssl.a ] || { echo "bearssl is missing!" >&2 && exit 1; }

./buildconf
./configure \
    --disable-shared \
    --enable-static \
    --without-libssh2 \
    --without-nghttp2 \
    --without-ssl \
    --with-bearssl \
    --with-pic \
    --with-ca-bundle=/etc/ssl/ca-bundle.crt \
    --build=$(uname -m)-lix-linux-musl \
    --prefix=

## explanation
#
# --disable-shared --enable-static:
#     ensure only static linking is done, respecting lix os' goals.
#
# --without-libssh2:
#     following alpine linux's lead on this. libssh2 has had maintenance
#     problems in the past.
#     see https://gitlab.alpinelinux.org/alpine/aports/issues/10222
#
# --without-nghttp2: nghttp2 does not seem to support bearssl at the moment.
#
# --without-ssl --with-bearssl:
#     the canonical way to use bearssl instead of openssl or libressl.
#
# --with-pic: prefer position-independent code objects.
#
# --with-ca-path: make sure curl looks in this directory for ssl certificates.
#
# --build: curl doesn't infer the right "triplet" without this.
#
# --prefix: respect lix os' simplified directory structure. no /usr/local.
