#!/bin/sh

set -e

LIBUSB_CFLAGS="-I/include/libusb-1.0" \
LIBUSB_LIBS="/lib/libusb-1.0.so" \
LIBUDEV_CFLAGS="-I/include" \
LIBUDEV_LIBS="/lib/libudev.so" \
./configure \
    --enable-libudev \
    --disable-libusb \
    --disable-libsystemd \
    --without-systemdsystemunitdir \
    --disable-polkit \
    --enable-ipcdir=/var/run/pcscd \
    --enable-usbdropdir=/lib/pcsc/drivers \
    --enable-static \
    --build="$(uname -m)-lix-linux-musl" \
    --host="$(uname -m)-lix-linux-musl" \
    --prefix=

## explanation
#
# LIBUSB_CFLAGS LIBUSB_LIBS LIBUDEV_CFLAGS LIBUDEV_LIBS:
#     helps 'configure' locate eudev's and libusb's headers and libraries.
#
# --enable-libudev: use eudev for detecting smdev hotplugging.
#
# --disable-libusb: don't use libusb-based polling.
#
# --disable-libsystemd: don't use libsystemd.
#
# --without-systemdsystemunitdir: don't build systemd service files.
#
# --disable-polkit: don't bother building support for policykit policies.
#
# --enable-ipcdir: put ipc sockets in /var/run/pcscd.
#
# --enable-usbdropdir: look for smartcard driver bundles in /lib/pcsc/drivers.
#
# --enable-static: build the static library as well.
#
# --build: make sure the build string gets set correctly.
#
# --host: make sure the host string gets set correctly.
#
# --prefix: respect the "no /usr/local" policy.
